/*
** Restricted Rights Legend
**
** Use, duplication or disclosure by the government is subject to restrictions
** as set forth in subparagraph (c)(1)(ii) of the Rights in Technical Data and
** Computer Software clause at DFARS 252.227-7013.
**
** Copyright (c) 1997 Lockheed Martin C2 Integration Systems
**
**
** File:         AgentAddress.java
**
** Description:  Contains the AgentAddress class that is internal to the KRIL.
**
*/
package kqml;

/**
 * A class internal to the KRIL.
 *
 * This class is used to parse and hold an ANS agent address lookup
 * - the ask-one performative reply ":content" field will contain 3
 *   colon separated fields of data.
 *
 * @author Peter Stevens
 * @version $Revision: 1.4 $
 */
class AgentAddress
{
    private static final char SEPARATOR  = ':';

    private String hostAddress  = null;
    private String hostPort     = null;
    private String name         = null;

    // Constructor
    AgentAddress(String ansReply)
    {
        int firstColon, secondColon;

        if ((firstColon=ansReply.indexOf(SEPARATOR)) > 0)
            if ((secondColon=ansReply.indexOf(SEPARATOR,firstColon+1)) > 0)
            {
                name        = ansReply.substring(0, firstColon);
                hostAddress = ansReply.substring(firstColon+1, secondColon);
                hostPort    = ansReply.substring(secondColon+1,
                                                    ansReply.length() - 1);
            }
    }

    protected String getName()        { return (name); }
    protected String getHostAddress() { return (hostAddress); }
    protected String getHostPort()    { return (hostPort); }
}
