/* File: ACP3.java
 * Contains: A class extended by ACP3 main-program classes
 * Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Created: January 1998
 * Updated: Tue Aug  4 14:04:34 1998 by Jeff Dalton
 * Copyright: (c) 1998, AIAI, University of Edinburgh
 */


package oplan.acp3;

import oplan.Release;
import oplan.util.*;


/**
 * A class extended by ACP3 main-program classes. 
 */

public class ACP3 {

    /** The ACP3 agent */

    public static ACP3 agent = null;

    public static ProcessViewer viewer;
    public static ProcessModel model;
    public static KqmlWatcher watcher;

    /** Create the ACP3 agent.  Only one instance should be created. */

    protected ACP3() {
	Debug.assert(agent == null);
    }

    /** shutdown performs any necessary cleanup before an exit. */

    protected void shutdown() {
	Debug.noteln("ACP3 shutdown");
    }

    /*
     * Static methods
     */

    /** 
     * A method to print the name of the system, the release version,
     * and the release date.
     */
    protected static void printGreeting(String name) {
	System.out.println(name
			   + ", version " + Release.version
			   + ", " + Release.date);
	System.out.println("");
    }

    /** 
     * ACP3.exit should always be called instead of System.exit.
     */
    protected static synchronized void exit(int status) {
	Debug.noteln("ACP3.exit called, status:", status);
	if (agent != null) {
	    Debug.noteln("Calling ACP3.agent.shutdown()");
	    agent.shutdown();
	}
	else
	    Debug.noteln("There is no ACP3.agent yet.");
	Debug.noteln("Final exit");
	System.exit(status);
    }

    /**
     * Command-line argument processing.
     */
    protected static void processCommandLineArguments(String[] argv) {
	try {
	    Parameters.processCommandLineArguments(argv);

	    if (Parameters.haveParameter("fontsize"))
		DefaultFont.setDefaultFontSize(
		    Parameters.getInt("fontsize"));

	    Debug.on = Parameters.getBoolean("debug", true);
	}
	catch (Exception e) { Debug.noteException(e); }
    }

}
