/* File: InfoFrame.java
 * Contains: ACP3 InfoFrame Class
 * Author: Austin Tate <a.tate@ed.ac.uk>
 * Created: Fri Jan 16 11:36:26 1998
 * Updated: Sat Aug 22 20:48:53 1998 by Jeff Dalton
 * Copyright: (c) 1998, AIAI, University of Edinburgh
 */

/** ACP3 - InfoFrame
    @version 0.1
    @author Austin Tate
 */

package oplan.acp3;

import java.awt.*;
import java.awt.image.*;
import java.util.*;
import oplan.util.*;

class InfoFrame extends Frame {
   
    public static final int SPLASH=0,
                            INTRODUCTION=1,
                            HELP=2,
                            COLOR_KEY=3,
                            DEMO_0=4,
                            DEMO_1=5,
                            DEMO_2=6,
                            DEMO_3=7,
                            DEMO_4=8,
                            DEMO_5=9,
                            DEMO_6=10;
                              
    private int maxImages=11;
    private Dimension myDimension;
    private Image offsc;
    private Image[] infoImage=new Image[maxImages];
    private ScrollPane infosp;
    private ImageCanvas infocv; //canvas in scroll pane
    private Panel infopn; //panel for buttons
                
    InfoFrame(String title, int w, int h) {
        super(title);
        myDimension=new Dimension(w,h);
        infoImage[SPLASH]=WaitImage.waitGetImage("IMG/splash.gif",this);
        infoImage[INTRODUCTION]=WaitImage.waitGetImage("IMG/intro.gif",this);
        infoImage[HELP]=WaitImage.waitGetImage("IMG/help.gif",this);
        infoImage[COLOR_KEY]=WaitImage.waitGetImage("IMG/color-key.gif",this);
        infoImage[DEMO_0]=WaitImage.waitGetImage("IMG/demo-0.gif",this);
        infoImage[DEMO_1]=WaitImage.waitGetImage("IMG/demo-1.gif",this);
        infoImage[DEMO_2]=WaitImage.waitGetImage("IMG/demo-2.gif",this);
        infoImage[DEMO_3]=WaitImage.waitGetImage("IMG/demo-3.gif",this);
        infoImage[DEMO_4]=WaitImage.waitGetImage("IMG/demo-4.gif",this);
        infoImage[DEMO_5]=WaitImage.waitGetImage("IMG/demo-5.gif",this);
        infoImage[DEMO_6]=WaitImage.waitGetImage("IMG/demo-6.gif",this);

        // initialise panels in frame.
        // setup MainFrame Layout
        GridBagLayout ifLayout=new GridBagLayout();
        GridBagConstraints gblConstraints=new GridBagConstraints();
        int componentHeight; //temp variable used to hold component height
        double componentRatio; //total of all MainFrame component ratios=1.0
        setLayout(ifLayout);
        gblConstraints.fill=GridBagConstraints.BOTH; //components fill their allocated areas
        gblConstraints.weightx=1.0; //stretch out to max. width (for one column layout)
                
        // Info Frame top area
        componentRatio=0.9;              
        gblConstraints.gridx=0;
        gblConstraints.gridy=0;
        gblConstraints.weighty=componentRatio;
        infosp=new ScrollPane();
        ifLayout.setConstraints(infosp,gblConstraints);
        add(infosp);
        infocv=new ImageCanvas(infoImage[SPLASH]);
        infosp.add(infocv);
                
        // Info Frame bottom (button) area
        componentRatio=0.1;
        componentHeight=(int)(h*componentRatio);              
        gblConstraints.gridx=0;
        gblConstraints.gridy=1;
        gblConstraints.weighty=componentRatio;
        infopn=new Panel();        
        infopn.setFont(DefaultFont.normal);
        ifLayout.setConstraints(infopn,gblConstraints);
        add(infopn);
        
        infopn.add(new Button("Intro"));
        infopn.add(new Button("Help"));
        infopn.add(new Button("Key"));
        infopn.add(new Button("Hide Info"));        
        pack();        
    }
    
    public Dimension minimumSize() {
         return myDimension;
    }
 
    public Dimension preferredSize() {
         return myDimension;
    }
     
    public boolean action(Event ev, Object arg) {
        if (ev.target instanceof Button) {
            if (arg.equals("Intro")) {
                setInfo(INTRODUCTION);                                 
                return true;
            }
            if (arg.equals("Help")) {
                setInfo(HELP);                                  
                return true;
            }
            if (arg.equals("Key")) {
                setInfo(COLOR_KEY);                              
                return true;
            }
            if (arg.equals("Hide Info")) {
                hide();
                return true;
            }
        }
        return false;
    }
    
    public boolean handleEvent(Event ev) {
        if (ev.id==Event.WINDOW_DESTROY) {
            this.hide(); //hide - but keep available
            Debug.noteln("InfoFrame hidden");
            return true;
        };
        return super.handleEvent(ev);
    }
   
    public void setInfo(int infoNumber) {
        if (infoNumber>=0 && infoNumber<maxImages) {
            infocv.setCanvasImage(infoImage[infoNumber]);
            infosp.invalidate();
            this.validate();
            if (!isShowing()) show();
        } else {
            Debug.noteln("setInfo index out of range: "+infoNumber);
        }
    }
 
}

