/* File: KqmlEvent.java
 * Contains: Class for information from Kqml messages
 * Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Created: February 1998
 * Updated: Thu Mar  9 18:54:07 2000 by Jeff Dalton
 * Copyright: (c) 1998, AIAI, University of Edinburgh
 */

package oplan.acp3;

import oplan.util.*;
import oplan.util.match.*;
import oplan.util.lisp.*;

import kqml.*;


/**
 * A KqmlEvent contains the information we care about from Kqml Messages.
 */

public class KqmlEvent implements KqmlSymbols {

    public String sender;
    public String performative;
    public LList content;

    public MatchEnv bindings;	// filled-in during analysis

    public KqmlEvent() {
    }

    public KqmlEvent(String sender, String performative, LList content) {
	this.sender = sender;
	this.performative = performative;
	this.content = content;
    }

    public KqmlEvent(LList file_message) {
	LList plist = file_message.cdr();
	this.sender = plist.get(K_SENDER).toString();
	this.performative = file_message.car().toString();
	this.content = (LList)plist.get(K_CONTENT);
    }

    public KqmlEvent(Message message) {
	// Do we need to convert to lower case, or is it already lower? /\/
	this.sender = message.getSender().toLowerCase();
	this.performative = message.getPerformative().toLowerCase();
	// Get the content step by step
	String cstr = message.getContents();
	Object cobj = new LispReader(cstr).safeRead();
	if (cobj instanceof Cons)
	    this.content = (LList)cobj;
	else {
	    Debug.warn("Trouble reading Message content:\n"
		       + "   \"" + cstr + "\"");
	    this.content = Lisp.NIL;
	}
    }

    public String toString() {
	return "KqmlEvent[" + sender + ", " + performative
	    + " (" + content.car() + " ... )]";
    }

//     public String toString() {
//         return "KqmlEvent[" + sender + ", " + performative + "\n" +
//                "    " + content + "\n]";
//     }

}

