/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Tue Apr  7 04:22:50 1998 by Jeff Dalton
 */

package oplan.util.lisp;

import java.util.*;
import oplan.util.*;


/** Non-empty lists. */

public class Cons extends List implements Cloneable {

    Object car;
    List cdr;			// only proper lists

    public Cons(Object car, List cdr) {
	this.car = car;
	this.cdr = cdr;
    }


    public boolean isNull() { return false; }

    public Object car() { return car; }
    public List cdr() { return cdr; }

    public int length() {
	int i = 1;
	for (Cons at = this; at.cdr != Lisp.NIL; at = (Cons)at.cdr, ++i)
	    {}
	return i;
    }

    public Object elementAt(int i) {
	int j = 0;
	for (List at = this; at != Lisp.NIL; at = ((Cons)at).cdr) {
	    if (j++ == i)
		return ((Cons)at).car;
	}
	return Lisp.NIL;
    }

    public Enumeration elements() {
	return new ConsEnumeration(this);
    }

    public boolean equal(List list) {
	return Lisp.equal(this, list);
    }

    public boolean find(Object a) {
	for (List at = this; at != Lisp.NIL; at = ((Cons)at).cdr) {
	    if (((Cons)at).car == a)
		return true;
	}
	return false;
    }

    public List append(List tail) {
	return new Cons(this.car, this.cdr.append(tail));
    }

    /*
     * Java Object stuff
     */

    public Object clone() {
	return append(Lisp.NIL);	// yes, that old trick
    }

    public boolean equals(Object a) {
	return Lisp.equal(this, a);
    }

    public int hashCode() {
	return car.hashCode();		// yes, I know that's totally losing
    }

    public String toString() {
	return Lisp.printToString(this);
    }

}


/** Cons enumerations. */

class ConsEnumeration extends ListEnumeration {

    protected List tail;

    ConsEnumeration(Cons c) {
	tail = c;
    }

    public boolean hasMoreElements() {
	return tail instanceof Cons;
    }

    public Object nextElement() {
	Object elt = ((Cons)tail).car;
	tail = ((Cons)tail).cdr;
	return elt;
    }

}
