/* File: ModelTest.java
 * Contains: Class for testing the ProcessModel class
 * Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Created: March 1998
 * Updated: Sat Apr 11 07:31:49 1998 by Jeff Dalton
 * Copyright: (c) 1998, AIAI, University of Edinburgh
 */

package oplan.test;

import oplan.util.*;
import oplan.util.lisp.*;
import oplan.acp3.*;

/**
 * A class for testing the process model.
 */

class ModelTest {

    static ProcessModel model;
    static MainFrame mf;

    public static void main(String[] argv) {

	model = new ProcessModel();
	mf = new MainFrame();
	model.setViewer(mf);
	mf.setProcessModel(model);

	model.initFromFile("ProcessModels/acp3-process.lsp");
	// model.addCoa(2);

	model.checkConnectivity();

	showNodes("Top-level nodes", model.topLevelNodes());
	showNodes("Initial nodes", model.initialNodes());
	showNodes("Final nodes", model.finalNodes());

//  	showNodes("Nodes in dff order",
//  		  model.nodesInDepthFirstFinishOrder());

	model.startAction("develop JFACC guidance", 2);
	Util.askLine("Continue?");
	model.startAction("assign weapons systems", 1);
	Util.askLine("Continue?");
	model.finishAction("develop COA", 3);
	Util.askLine("Continue?");
	model.finishAction("develop COA", 1);
	Util.askLine("Continue?");
	model.finishAction("develop COA", 2);

    }

    private static void showNodes(String title, List nodes) {
	Debug.noteln(title);
	Debug.noteEnumeration(nodes.elements());
    }

}
