/* File: ReadKqmlLog.java
 * Contains: Main program for looking at Kqml log files
 * Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Created: January 1998
 * Updated: Thu Mar  9 19:10:53 2000 by Jeff Dalton
 * Copyright: (c) 1998, AIAI, University of Edinburgh
 */

package oplan.test;

import java.util.*;
import java.io.*;
import oplan.util.*;
import oplan.util.lisp.*;
import oplan.util.match.*;
import oplan.acp3.*;


/**
 * A class for testing some of the ways we process Kqml messages.<p>
 */

class ReadKqmlLog implements KqmlSymbols {

    // WatcherListener listener = new TrivialWatcherListener();
    // KqmlWatcher watcher = new KqmlWatcher(listener);

    static MainFrame viewer = null;
    static ProcessModel model = null;
    static KqmlWatcher watcher = null;

    static boolean describe = false;
    static boolean useModel = true;
    static boolean useViewer = true;

    public static void main(String[] argv) {

	Vector files = new Vector();

	// Process argv
	Enumeration args = Seq.elements(argv);
	while (args.hasMoreElements()) {
	    String arg = (String)args.nextElement();
	    if (arg.equals("-describe")) {
		describe = true;
		useModel = false;
		useViewer = false;
	    }
	    else
		files.addElement(arg);
	}

	// Set up components
	watcher = new KqmlWatcher(null);
	if (useModel) {
	    model = new ProcessModel();
	    watcher.setListener(model);
	    model.initFromFile("ProcessModels/acp3-process.lsp");
	    if (useViewer) {
		viewer = new MainFrame();
		model.setViewer(viewer);
		viewer.setProcessModel(model);
	    }
	    else {
		System.out.println("Can't yet not use viewer.");
		System.exit(1);
	    }
	}
	else {
	    // Don't use a ProcessModel
	    watcher.setListener(new TrivialWatcherListener());
	}

	Debug.noteln("watcher.listener", watcher.listener);

	// Process files
	Enumeration fe = files.elements();
	while (fe.hasMoreElements()) {
	    String name = (String)fe.nextElement();
	    scanLog(name);
	}

    }

    static void scanLog(String filename) {
	KqmlLogReader lin;
	KqmlEvent event;
	Object message;

	Debug.noteln("Reading file", filename);

	long time = 0;

	try { 
	    lin = KqmlLogReader.newInstance(filename); 
	    while ((message = lin.nextMessage()) != Lisp.EOF) {
		long m_t = KqmlLogReader.messageDelta_t((LList)message);
		if (m_t > time) {
		    System.out.println("... " + (m_t - time) + " ... ms");
		    time = m_t;
		}
		if (!describe) {
		    // Print long description
		    showMessage((LList)message);
		    // Wait for the user
		    Util.askLine("ok?");
		}
		event = new KqmlEvent((LList)message);
		watcher.interpret(event);
	    }
	}
	catch (FileNotFoundException e) {
	    System.out.println(e);
	    System.exit(1);
	}

    }

    static void showMessage(LList message) {
	Symbol performative = (Symbol)message.car();
	LList plist = message.cdr();
	LList content = (LList)plist.get(K_CONTENT);
	String sender = plist.get(K_SENDER).toString();
	Object sent_to = plist.get(K_SENT_TO);
	Object reply_with = plist.get(K_REPLY_WITH);

	System.out.println
	    ("--> " + sender + " sent " + performative
	     + " to " + (sent_to != null ? sent_to : "unknown")
	     + ", reply with " + reply_with
	     + "\n"
	     + "content = " + content
	     + "\n");
    }

}
