/* Author: Jeff Dalton <J.Dalton@ed.ac.uk>
 * Updated: Wed Aug 25 01:24:33 1999 by Jeff Dalton
 */

package oplan.util.lisp;

import java.util.*;
import oplan.util.*;

/**
 * A Collector that uses a LList to hold the elements and that provides
 * a number of different ways to add elements.
 */

public class ListCollector implements Collector {

    Cons head = new Cons(Lisp.NIL, Lisp.NIL);
    Cons tail = head;

    public ListCollector() {
    }

    public void addElement(Object e) {
	tail.cdr = new Cons(e, Lisp.NIL);
	tail = (Cons)tail.cdr;
    }

    public void pushElement(Object e) {
	head.cdr = new Cons(e, head.cdr);
	if (tail == head)
	    tail = (Cons)tail.cdr;
    }

    public Enumeration elements() {
	return head.cdr.elements();
    }

    public LList contents() {
	return head.cdr;
    }

    public void concList(LList l) {
	tail.cdr = l;
	tail = tail.lastCons();
    }

    public void appendList(LList l) {
	concList((LList)l.clone());
    }

    public Function1 elementAdder() {
	return new adderFunction() {
	    public Object funcall(Object e) {
		addElement(e);
		return null;
	    }
	};
    }

    public Function1 elementPusher() {
	return new adderFunction() {
	    public Object funcall(Object e) {
		pushElement(e);
		return null;
	    }
	};
    }

    public Function1 listAppender() {
	return new adderFunction() {
	    public Object funcall(Object l) {
		appendList((LList)l);
		return null;
	    }
	};
    }

    public Function1 listConcer() {
	return new adderFunction() {
	    public Object funcall(Object l) {
		concList((LList)l);
		return null;
	    }
	};
    }

    protected static interface adderFunction extends Function1 {
    }

}
